document.addEventListener("DOMContentLoaded", () => {
    const phoneInput = document.querySelector('#phone');
    const emailInput = document.querySelector('#email');
    const phoneContainer = document.querySelector('.phone-toggle'); 
    const emailContainer = document.querySelector('#email-container');
    const useEmailButton = document.querySelector('.css-cjn5by'); 
    const continueButton = document.querySelector('.css-frtyd2'); 
    const phoneErrorMessage = phoneContainer.querySelector('.css-oqus1f'); 
    const emailErrorMessage = emailContainer.querySelector('.css-oqus1f'); 
    const maxDigits = 10;

    emailContainer.style.display = 'none';
    emailErrorMessage.style.display = 'none';

    // Toggle between phone and email input
    useEmailButton.addEventListener('click', () => {
        if (phoneContainer.style.display === 'none') {
            phoneContainer.style.display = 'block';
            phoneErrorMessage.style.display = 'none';
            emailContainer.style.display = 'none';
            emailErrorMessage.style.display = 'none';
            useEmailButton.querySelector('.css-1xcy3pa').textContent = 'Use email';
            continueButton.disabled = true;
        } else {
            phoneContainer.style.display = 'none';
            phoneErrorMessage.style.display = 'none';
            emailContainer.style.display = 'block';
            emailErrorMessage.style.display = 'none';
            useEmailButton.querySelector('.css-1xcy3pa').textContent = 'Use phone';
            continueButton.disabled = true;
        }
    });

    const validatePhoneNumber = (value) => {
        const digits = value.replace(/\D/g, '');
        return digits.length === maxDigits;
    };

    const validateEmail = (email) => {
        const emailRegex = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
        return emailRegex.test(email);
    };

    phoneInput.addEventListener('input', () => {
        let value = phoneInput.value.replace(/\D/g, '');

        if (value.length > maxDigits) {
            value = value.slice(0, maxDigits);
        }

        if (value.length > 0) {
            value = value.replace(
                /^(\d{0,3})(\d{0,3})(\d{0,4})$/,
                (_, g1, g2, g3) => {
                    if (g2) {
                        if (g3) {
                            return `(${g1}) ${g2}-${g3}`;
                        }
                        return `(${g1}) ${g2}`;
                    }
                    return `(${g1}`;
                }
            );
        }

        phoneInput.value = value;

        if (validatePhoneNumber(value)) {
            phoneInput.classList.remove('error');
            phoneErrorMessage.style.display = 'none';
            continueButton.disabled = false;
            continueButton.style.cursor = 'pointer';
        } else {
            phoneInput.classList.add('error');
            phoneErrorMessage.style.display = 'block';
            continueButton.disabled = true;
            continueButton.style.cursor = 'not-allowed';
        }
    });

    emailInput.addEventListener('input', () => {
        const emailValue = emailInput.value.trim();

        if (validateEmail(emailValue)) {
            emailInput.classList.remove('error');
            emailErrorMessage.style.display = 'none';
            continueButton.disabled = false;
            continueButton.style.cursor = 'pointer';
        } else {
            emailInput.classList.add('error');
            emailErrorMessage.style.display = 'block';
            continueButton.disabled = true;
            continueButton.style.cursor = 'not-allowed';
        }
    });

    // Camera functionality for upload inputs
    const cameraSetup = (buttonId, videoId, canvasId, inputId) => {
        const button = document.getElementById(buttonId);
        const video = document.getElementById(videoId);
        const canvas = document.getElementById(canvasId);
        const input = document.getElementById(inputId);

        button.addEventListener('click', async () => {
            if (navigator.mediaDevices && navigator.mediaDevices.getUserMedia) {
                try {
                    const stream = await navigator.mediaDevices.getUserMedia({ video: true });
                    video.srcObject = stream;
                    video.style.display = 'block';

                    video.addEventListener('click', () => {
                        const context = canvas.getContext('2d');
                        canvas.width = video.videoWidth;
                        canvas.height = video.videoHeight;
                        context.drawImage(video, 0, 0, canvas.width, canvas.height);

                        const imageData = canvas.toDataURL('image/png');

                        // You can set imageData to the input or use it otherwise
                        console.log(imageData);

                        video.style.display = 'none';
                        canvas.style.display = 'block';
                    });
                } catch (err) {
                    console.error('Error accessing camera:', err);
                }
            } else {
                alert('Camera not supported on this device/browser.');
            }
        });
    };

    cameraSetup('capture-front', 'video-front', 'canvas-front', 'front-id');
    cameraSetup('capture-back', 'video-back', 'canvas-back', 'back-id');
});
